/* Emacs: this is -*- C -*- code, */
/* generated 2011-11-08T22:50:25-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_5 3
#define LABEL_1_6 5
#define LABEL_1_7 7
#define LABEL_1_4 9
#define LABEL_1_8 11
#define LABEL_1_9 13
#define LABEL_1_10 15
#define LABEL_1_11 17
#define LABEL_1_12 19
#define LABEL_1_13 21
#define LABEL_1_14 23
#define LABEL_1_15 25
#define LABEL_1_16 27
#define LABEL_1_17 29
#define LABEL_1_19 31
#define LABEL_1_20 33
#define LABEL_1_21 35
#define LABEL_1_22 37
#define LABEL_1_23 39
#define LABEL_1_24 41
#define LABEL_1_25 43
#define LABEL_1_26 45
#define LABEL_1_18 47
#define LABEL_1_27 49
#define LABEL_1_29 51
#define LABEL_1_30 53
#define ENVIRONMENT_LABEL_1_3 70
#define DEBUGGING_LABEL_1_2 69
#define OBJECT_1_9 68
#define OBJECT_1_8 67
#define OBJECT_1_7 66
#define OBJECT_1_6 65
#define OBJECT_1_5 64
#define OBJECT_1_4 63
#define OBJECT_1_3 62
#define OBJECT_1_2 61
#define OBJECT_1_1 60
#define OBJECT_1_0 59
#define EXECUTE_CACHE_1_31 55
#define EXECUTE_CACHE_1_28 57
#define FREE_REFERENCES_LABEL_1_0 54
#define NUMBER_OF_LINKER_SECTIONS_1_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
equals_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd266;
  machine_word Wrd265;
  machine_word Wrd261;
  machine_word Wrd258;
  machine_word Wrd257;
  machine_word Wrd256;
  machine_word Wrd255;
  machine_word Wrd254;
  machine_word Wrd253;
  machine_word Wrd240;
  machine_word Wrd238;
  machine_word Wrd228;
  machine_word Wrd232;
  machine_word Wrd231;
  machine_word Wrd234;
  machine_word Wrd233;
  machine_word Wrd227;
  machine_word Wrd226;
  machine_word Wrd216;
  machine_word Wrd220;
  machine_word Wrd219;
  machine_word Wrd222;
  machine_word Wrd221;
  machine_word Wrd251;
  machine_word Wrd248;
  machine_word Wrd215;
  machine_word Wrd214;
  machine_word Wrd213;
  machine_word Wrd246;
  machine_word Wrd243;
  machine_word Wrd202;
  machine_word Wrd206;
  machine_word Wrd205;
  machine_word Wrd204;
  machine_word Wrd210;
  machine_word Wrd200;
  machine_word Wrd278;
  machine_word Wrd275;
  machine_word Wrd199;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd273;
  machine_word Wrd270;
  machine_word Wrd288;
  machine_word Wrd285;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd193;
  machine_word Wrd283;
  machine_word Wrd280;
  machine_word Wrd298;
  machine_word Wrd295;
  machine_word Wrd191;
  machine_word Wrd190;
  machine_word Wrd189;
  machine_word Wrd293;
  machine_word Wrd290;
  machine_word Wrd308;
  machine_word Wrd187;
  machine_word Wrd185;
  machine_word Wrd303;
  machine_word Wrd300;
  machine_word Wrd183;
  machine_word Wrd182;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd92;
  machine_word Wrd88;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd70;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd78;
  machine_word Wrd68;
  machine_word Wrd105;
  machine_word Wrd102;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd115;
  machine_word Wrd112;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd110;
  machine_word Wrd107;
  machine_word Wrd125;
  machine_word Wrd122;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd135;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd130;
  machine_word Wrd127;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd36;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd44;
  machine_word Wrd34;
  machine_word Wrd146;
  machine_word Wrd143;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd141;
  machine_word Wrd138;
  machine_word Wrd156;
  machine_word Wrd153;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd151;
  machine_word Wrd148;
  machine_word Wrd166;
  machine_word Wrd163;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd176;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd171;
  machine_word Wrd168;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd318;
  machine_word Wrd315;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd311;
  machine_word Wrd310;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_19;

    case 1:
      current_block = (Rpc - LABEL_1_6);
      goto continuation_9;

    case 2:
      current_block = (Rpc - LABEL_1_7);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_1_4);
      goto eqvP_32;

    case 4:
      current_block = (Rpc - LABEL_1_8);
      goto label_51;

    case 5:
      current_block = (Rpc - LABEL_1_9);
      goto label_42;

    case 6:
      current_block = (Rpc - LABEL_1_10);
      goto label_41;

    case 7:
      current_block = (Rpc - LABEL_1_11);
      goto label_40;

    case 8:
      current_block = (Rpc - LABEL_1_12);
      goto label_39;

    case 9:
      current_block = (Rpc - LABEL_1_13);
      goto label_38;

    case 10:
      current_block = (Rpc - LABEL_1_14);
      goto label_37;

    case 11:
      current_block = (Rpc - LABEL_1_15);
      goto label_36;

    case 12:
      current_block = (Rpc - LABEL_1_16);
      goto label_35;

    case 13:
      current_block = (Rpc - LABEL_1_17);
      goto label_34;

    case 14:
      current_block = (Rpc - LABEL_1_19);
      goto label_50;

    case 15:
      current_block = (Rpc - LABEL_1_20);
      goto label_49;

    case 16:
      current_block = (Rpc - LABEL_1_21);
      goto label_48;

    case 17:
      current_block = (Rpc - LABEL_1_22);
      goto label_47;

    case 18:
      current_block = (Rpc - LABEL_1_23);
      goto label_45;

    case 19:
      current_block = (Rpc - LABEL_1_24);
      goto label_43;

    case 20:
      current_block = (Rpc - LABEL_1_25);
      goto label_44;

    case 21:
      current_block = (Rpc - LABEL_1_26);
      goto label_46;

    case 22:
      current_block = (Rpc - LABEL_1_18);
      goto continuation_16;

    case 23:
      current_block = (Rpc - LABEL_1_27);
      goto continuation_30;

    case 24:
      current_block = (Rpc - LABEL_1_29);
      goto continuation_17;

    case 25:
      current_block = (Rpc - LABEL_1_30);
      goto continuation_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (eqvP_53)
DEFLABEL (eqvP_32)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_95;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  (Wrd7.Obj) = (MAKE_OBJECT (26, (Wrd10.uLng)));
  (Wrd310.Obj) = ((SCHEME_OBJECT) 26);
  if (! ((Wrd310.uLng) == 26))
    goto label_112;
  (Wrd311.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if (! (((unsigned long) (Wrd311.Lng)) < ((unsigned long) (1 << TYPE_CODE_LENGTH))))
    goto label_112;
  Wrd11 = Wrd10;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd11.Obj) == (Wrd13.Obj))
    goto label_88;

DEFLABEL (label_87)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd168.Obj) = (current_block [OBJECT_1_1]);
  (Wrd171.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd171.Lng))))
    goto label_86;
  (Wrd19.uLng) = (OBJECT_DATUM (Wrd168.Obj));
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd19.Obj) == (Wrd21.Obj))
    goto label_79;

DEFLABEL (label_85)
  (Wrd158.Obj) = (current_block [OBJECT_1_2]);
  (Wrd161.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd161.Lng))))
    goto label_84;
  (Wrd23.uLng) = (OBJECT_DATUM (Wrd158.Obj));
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd23.Obj) == (Wrd25.Obj))
    goto label_79;

DEFLABEL (label_83)
  (Wrd148.Obj) = (current_block [OBJECT_1_3]);
  (Wrd151.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd151.Lng))))
    goto label_82;
  (Wrd27.uLng) = (OBJECT_DATUM (Wrd148.Obj));
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd27.Obj) == (Wrd29.Obj))
    goto label_79;

DEFLABEL (label_81)
  (Wrd138.Obj) = (current_block [OBJECT_1_4]);
  (Wrd141.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd141.Lng))))
    goto label_80;
  (Wrd31.uLng) = (OBJECT_DATUM (Wrd138.Obj));
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd31.Obj) == (Wrd33.Obj))
    goto label_79;

DEFLABEL (label_78)
  (Wrd34.Obj) = (current_block [OBJECT_1_5]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd44.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 60L) < ((unsigned long) (Wrd44.Lng)))
    goto label_55;

DEFLABEL (label_54)
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_55)
  (Wrd38.uLng) = (OBJECT_DATUM (Wrd34.Obj));
  (Wrd39.Obj) = (Rsp [1]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd38.Obj) == (Wrd40.Obj))
    goto label_57;
  (Wrd36.Obj) = (current_block [OBJECT_1_7]);
  goto label_56;

DEFLABEL (label_57)
  (Wrd36.Obj) = (current_block [OBJECT_1_6]);

DEFLABEL (label_56)
DEFLABEL (label_77)
  Rsp = (& (Rsp [3]));
  if ((Wrd36.Obj) == ((SCHEME_OBJECT) 0))
    goto label_61;

DEFLABEL (label_76)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_6]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd127.Obj) = (current_block [OBJECT_1_1]);
  (Wrd130.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd130.Lng))))
    goto label_75;
  (Wrd53.uLng) = (OBJECT_DATUM (Wrd127.Obj));
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd53.Obj) == (Wrd55.Obj))
    goto label_68;

DEFLABEL (label_74)
  (Wrd117.Obj) = (current_block [OBJECT_1_2]);
  (Wrd120.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd120.Lng))))
    goto label_73;
  (Wrd57.uLng) = (OBJECT_DATUM (Wrd117.Obj));
  (Wrd58.Obj) = (Rsp [0]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if ((Wrd57.Obj) == (Wrd59.Obj))
    goto label_68;

DEFLABEL (label_72)
  (Wrd107.Obj) = (current_block [OBJECT_1_3]);
  (Wrd110.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd110.Lng))))
    goto label_71;
  (Wrd61.uLng) = (OBJECT_DATUM (Wrd107.Obj));
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if ((Wrd61.Obj) == (Wrd63.Obj))
    goto label_68;

DEFLABEL (label_70)
  (Wrd97.Obj) = (current_block [OBJECT_1_4]);
  (Wrd100.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd100.Lng))))
    goto label_69;
  (Wrd65.uLng) = (OBJECT_DATUM (Wrd97.Obj));
  (Wrd66.Obj) = (Rsp [0]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if ((Wrd65.Obj) == (Wrd67.Obj))
    goto label_68;

DEFLABEL (label_67)
  (Wrd68.Obj) = (current_block [OBJECT_1_5]);
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd78.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 60L) < ((unsigned long) (Wrd78.Lng))))
    goto label_54;
  (Wrd72.uLng) = (OBJECT_DATUM (Wrd68.Obj));
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd72.Obj) == (Wrd74.Obj))
    goto label_59;
  (Wrd70.Obj) = (current_block [OBJECT_1_7]);
  goto label_58;

DEFLABEL (label_59)
  (Wrd70.Obj) = (current_block [OBJECT_1_6]);

DEFLABEL (label_58)
DEFLABEL (label_66)
  Rsp = (& (Rsp [3]));
  if ((Wrd70.Obj) == ((SCHEME_OBJECT) 0))
    goto label_61;

DEFLABEL (label_65)
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 26))
    goto label_64;
  (Wrd82.Obj) = (Rsp [1]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd83.uLng) == 26))
    goto label_64;
  if ((Wrd80.Obj) == (Wrd82.Obj))
    goto label_62;

DEFLABEL (label_61)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_60)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_62)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_18]))));
  (* (--Rsp)) = (Wrd92.Obj);

DEFLABEL (label_63)
  (Wrd266.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd266.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_28]));

DEFLABEL (label_64)
  (Wrd84.Obj) = (Rsp [0]);
  (Wrd85.Obj) = (Rsp [1]);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_17]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_34)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_61;
  goto label_62;

DEFLABEL (label_68)
  Rsp = (& (Rsp [2]));
  goto label_65;

DEFLABEL (label_69)
  (Wrd102.Obj) = (Rsp [0]);
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_16]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_35)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_67;
  goto label_68;

DEFLABEL (label_71)
  (Wrd112.Obj) = (Rsp [0]);
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_15]))));
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd107.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_36)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_70;
  goto label_68;

DEFLABEL (label_73)
  (Wrd122.Obj) = (Rsp [0]);
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_14]))));
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd117.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_37)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;
  goto label_68;

DEFLABEL (label_75)
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_13]))));
  (* (--Rsp)) = (Wrd135.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd127.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_38)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_74;
  goto label_68;

DEFLABEL (label_79)
  Rsp = (& (Rsp [2]));
  goto label_76;

DEFLABEL (label_80)
  (Wrd143.Obj) = (Rsp [0]);
  (Wrd146.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_12]))));
  (* (--Rsp)) = (Wrd146.Obj);
  (* (--Rsp)) = (Wrd143.Obj);
  (* (--Rsp)) = (Wrd138.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_39)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_78;
  goto label_79;

DEFLABEL (label_82)
  (Wrd153.Obj) = (Rsp [0]);
  (Wrd156.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_11]))));
  (* (--Rsp)) = (Wrd156.Obj);
  (* (--Rsp)) = (Wrd153.Obj);
  (* (--Rsp)) = (Wrd148.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_40)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_81;
  goto label_79;

DEFLABEL (label_84)
  (Wrd163.Obj) = (Rsp [0]);
  (Wrd166.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_10]))));
  (* (--Rsp)) = (Wrd166.Obj);
  (* (--Rsp)) = (Wrd163.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_41)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_83;
  goto label_79;

DEFLABEL (label_86)
  (Wrd176.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_9]))));
  (* (--Rsp)) = (Wrd176.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd168.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_42)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_85;
  goto label_79;

DEFLABEL (label_88)
  (Wrd178.Obj) = (Rsp [0]);
  (Wrd179.uLng) = (OBJECT_TYPE (Wrd178.Obj));
  if ((Wrd179.uLng) == 26)
    goto label_61;
  (Wrd182.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd182.Obj);
  (Wrd183.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd183.Obj);
  (Wrd300.Obj) = (current_block [OBJECT_1_1]);
  (Wrd303.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd303.Lng))))
    goto label_111;
  (Wrd185.uLng) = (OBJECT_DATUM (Wrd300.Obj));
  (Wrd187.uLng) = (OBJECT_TYPE (Wrd183.Obj));
  if ((Wrd185.Obj) == (Wrd187.Obj))
    goto label_104;

DEFLABEL (label_110)
  (Wrd290.Obj) = (current_block [OBJECT_1_2]);
  (Wrd293.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd293.Lng))))
    goto label_109;
  (Wrd189.uLng) = (OBJECT_DATUM (Wrd290.Obj));
  (Wrd190.Obj) = (Rsp [0]);
  (Wrd191.uLng) = (OBJECT_TYPE (Wrd190.Obj));
  if ((Wrd189.Obj) == (Wrd191.Obj))
    goto label_104;

DEFLABEL (label_108)
  (Wrd280.Obj) = (current_block [OBJECT_1_3]);
  (Wrd283.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd283.Lng))))
    goto label_107;
  (Wrd193.uLng) = (OBJECT_DATUM (Wrd280.Obj));
  (Wrd194.Obj) = (Rsp [0]);
  (Wrd195.uLng) = (OBJECT_TYPE (Wrd194.Obj));
  if ((Wrd193.Obj) == (Wrd195.Obj))
    goto label_104;

DEFLABEL (label_106)
  (Wrd270.Obj) = (current_block [OBJECT_1_4]);
  (Wrd273.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd273.Lng))))
    goto label_105;
  (Wrd197.uLng) = (OBJECT_DATUM (Wrd270.Obj));
  (Wrd198.Obj) = (Rsp [0]);
  (Wrd199.uLng) = (OBJECT_TYPE (Wrd198.Obj));
  if ((Wrd197.Obj) == (Wrd199.Obj))
    goto label_104;

DEFLABEL (label_103)
  (Wrd200.Obj) = (current_block [OBJECT_1_5]);
  (* (--Rsp)) = (Wrd200.Obj);
  (Wrd210.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 60L) < ((unsigned long) (Wrd210.Lng))))
    goto label_54;
  (Wrd204.uLng) = (OBJECT_DATUM (Wrd200.Obj));
  (Wrd205.Obj) = (Rsp [1]);
  (Wrd206.uLng) = (OBJECT_TYPE (Wrd205.Obj));
  if ((Wrd204.Obj) == (Wrd206.Obj))
    goto label_90;
  (Wrd202.Obj) = (current_block [OBJECT_1_7]);
  goto label_89;

DEFLABEL (label_90)
  (Wrd202.Obj) = (current_block [OBJECT_1_6]);

DEFLABEL (label_89)
DEFLABEL (label_102)
  Rsp = (& (Rsp [3]));
  if ((Wrd202.Obj) == ((SCHEME_OBJECT) 0))
    goto label_94;

DEFLABEL (label_93)
  (Wrd253.Obj) = (Rsp [0]);
  (Wrd254.uLng) = (OBJECT_TYPE (Wrd253.Obj));
  if (! ((Wrd254.uLng) == 26))
    goto label_92;
  (Wrd255.Obj) = (Rsp [1]);
  (Wrd256.uLng) = (OBJECT_TYPE (Wrd255.Obj));
  if (! ((Wrd256.uLng) == 26))
    goto label_92;
  if (! ((Wrd253.Obj) == (Wrd255.Obj)))
    goto label_61;

DEFLABEL (label_91)
  (Wrd265.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_27]))));
  (* (--Rsp)) = (Wrd265.Obj);
  goto label_63;

DEFLABEL (label_92)
  (Wrd257.Obj) = (Rsp [0]);
  (Wrd258.Obj) = (Rsp [1]);
  (Wrd261.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_26]))));
  (* (--Rsp)) = (Wrd261.Obj);
  (* (--Rsp)) = (Wrd258.Obj);
  (* (--Rsp)) = (Wrd257.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_46)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_61;
  goto label_91;

DEFLABEL (label_94)
  (Wrd243.Obj) = (current_block [OBJECT_1_8]);
  (Wrd246.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd246.Lng))))
    goto label_101;
  (Wrd213.uLng) = (OBJECT_DATUM (Wrd243.Obj));
  (Wrd214.Obj) = (Rsp [1]);
  (Wrd215.uLng) = (OBJECT_TYPE (Wrd214.Obj));
  if (! ((Wrd213.Obj) == (Wrd215.Obj)))
    goto label_61;

DEFLABEL (label_100)
  (Wrd221.Obj) = (Rsp [0]);
  (Wrd222.uLng) = (OBJECT_TYPE (Wrd221.Obj));
  if (! ((Wrd222.uLng) == 10))
    goto label_99;
  (Wrd219.pObj) = (OBJECT_ADDRESS (Wrd221.Obj));
  (Wrd220.Obj) = ((Wrd219.pObj) [0]);
  (Wrd216.Obj) = (MAKE_OBJECT (26, (Wrd220.uLng)));

DEFLABEL (label_98)
  (Wrd227.Lng) = (FIXNUM_TO_LONG (Wrd216.Obj));
  if (! ((Wrd227.Lng) == 0))
    goto label_61;
  (Wrd233.Obj) = (Rsp [1]);
  (Wrd234.uLng) = (OBJECT_TYPE (Wrd233.Obj));
  if (! ((Wrd234.uLng) == 10))
    goto label_97;
  (Wrd231.pObj) = (OBJECT_ADDRESS (Wrd233.Obj));
  (Wrd232.Obj) = ((Wrd231.pObj) [0]);
  (Wrd228.Obj) = (MAKE_OBJECT (26, (Wrd232.uLng)));

DEFLABEL (label_96)
  (Wrd240.Lng) = (FIXNUM_TO_LONG (Wrd228.Obj));
  if (! ((Wrd240.Lng) == 0))
    goto label_61;

DEFLABEL (label_95)
  Rvl = (current_block [OBJECT_1_6]);
  goto label_60;

DEFLABEL (label_97)
  (Wrd238.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_25]))));
  (* (--Rsp)) = (Wrd238.Obj);
  (* (--Rsp)) = (Wrd233.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_9]), 1);

DEFLABEL (label_44)
  (Wrd228.Obj) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (Wrd226.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_24]))));
  (* (--Rsp)) = (Wrd226.Obj);
  (* (--Rsp)) = (Wrd221.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_9]), 1);

DEFLABEL (label_43)
  (Wrd216.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_101)
  (Wrd248.Obj) = (Rsp [1]);
  (Wrd251.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_23]))));
  (* (--Rsp)) = (Wrd251.Obj);
  (* (--Rsp)) = (Wrd248.Obj);
  (* (--Rsp)) = (Wrd243.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_45)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_61;
  goto label_100;

DEFLABEL (label_104)
  Rsp = (& (Rsp [2]));
  goto label_93;

DEFLABEL (label_105)
  (Wrd275.Obj) = (Rsp [0]);
  (Wrd278.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_22]))));
  (* (--Rsp)) = (Wrd278.Obj);
  (* (--Rsp)) = (Wrd275.Obj);
  (* (--Rsp)) = (Wrd270.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_47)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_103;
  goto label_104;

DEFLABEL (label_107)
  (Wrd285.Obj) = (Rsp [0]);
  (Wrd288.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_21]))));
  (* (--Rsp)) = (Wrd288.Obj);
  (* (--Rsp)) = (Wrd285.Obj);
  (* (--Rsp)) = (Wrd280.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_48)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_106;
  goto label_104;

DEFLABEL (label_109)
  (Wrd295.Obj) = (Rsp [0]);
  (Wrd298.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_20]))));
  (* (--Rsp)) = (Wrd298.Obj);
  (* (--Rsp)) = (Wrd295.Obj);
  (* (--Rsp)) = (Wrd290.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_49)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_108;
  goto label_104;

DEFLABEL (label_111)
  (Wrd308.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_19]))));
  (* (--Rsp)) = (Wrd308.Obj);
  (* (--Rsp)) = (Wrd183.Obj);
  (* (--Rsp)) = (Wrd300.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_50)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_110;
  goto label_104;

DEFLABEL (label_112)
  (Wrd315.Obj) = (Rsp [1]);
  (Wrd318.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_8]))));
  (* (--Rsp)) = (Wrd318.Obj);
  (* (--Rsp)) = (Wrd315.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 2);

DEFLABEL (label_51)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_87;
  goto label_88;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_1_18);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_29]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_28]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_1_29);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_31]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_1_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_61;
  goto label_65;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_1_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_61;
  goto label_76;

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_1_27);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_28]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_1_30);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_31]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_1_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_94;
  goto label_93;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_5 3
#define LABEL_2_6 5
#define LABEL_2_7 7
#define LABEL_2_4 9
#define LABEL_2_8 11
#define LABEL_2_9 13
#define LABEL_2_10 15
#define LABEL_2_11 17
#define LABEL_2_12 19
#define LABEL_2_13 21
#define LABEL_2_14 23
#define LABEL_2_15 25
#define LABEL_2_16 27
#define LABEL_2_17 29
#define LABEL_2_20 31
#define LABEL_2_21 33
#define LABEL_2_23 35
#define LABEL_2_24 37
#define LABEL_2_26 39
#define LABEL_2_27 41
#define LABEL_2_28 43
#define LABEL_2_29 45
#define LABEL_2_31 47
#define LABEL_2_18 49
#define LABEL_2_30 51
#define LABEL_2_32 53
#define LABEL_2_39 55
#define LABEL_2_41 57
#define LABEL_2_42 59
#define LABEL_2_19 61
#define LABEL_2_43 63
#define LABEL_2_44 65
#define LABEL_2_34 67
#define LABEL_2_37 69
#define LABEL_2_35 71
#define LABEL_2_38 73
#define LABEL_2_40 75
#define LABEL_2_46 77
#define LABEL_2_49 79
#define LABEL_2_47 81
#define LABEL_2_51 83
#define ENVIRONMENT_LABEL_2_3 118
#define DEBUGGING_LABEL_2_2 117
#define OBJECT_2_15 116
#define OBJECT_2_14 115
#define OBJECT_2_13 114
#define OBJECT_2_12 113
#define OBJECT_2_11 112
#define OBJECT_2_10 111
#define OBJECT_2_9 110
#define OBJECT_2_8 109
#define OBJECT_2_7 108
#define OBJECT_2_6 107
#define OBJECT_2_5 106
#define OBJECT_2_4 105
#define OBJECT_2_3 104
#define OBJECT_2_2 103
#define OBJECT_2_1 102
#define OBJECT_2_0 101
#define EXECUTE_CACHE_2_52 85
#define EXECUTE_CACHE_2_50 87
#define EXECUTE_CACHE_2_48 89
#define EXECUTE_CACHE_2_45 91
#define EXECUTE_CACHE_2_36 93
#define EXECUTE_CACHE_2_33 95
#define EXECUTE_CACHE_2_25 97
#define EXECUTE_CACHE_2_22 99
#define FREE_REFERENCES_LABEL_2_0 84
#define NUMBER_OF_LINKER_SECTIONS_2_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
equals_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd35;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd14;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd233;
  machine_word Wrd232;
  machine_word Wrd228;
  machine_word Wrd225;
  machine_word Wrd224;
  machine_word Wrd223;
  machine_word Wrd222;
  machine_word Wrd221;
  machine_word Wrd220;
  machine_word Wrd219;
  machine_word Wrd218;
  machine_word Wrd206;
  machine_word Wrd210;
  machine_word Wrd209;
  machine_word Wrd208;
  machine_word Wrd214;
  machine_word Wrd204;
  machine_word Wrd245;
  machine_word Wrd242;
  machine_word Wrd203;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd240;
  machine_word Wrd237;
  machine_word Wrd255;
  machine_word Wrd252;
  machine_word Wrd199;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd250;
  machine_word Wrd247;
  machine_word Wrd265;
  machine_word Wrd262;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd193;
  machine_word Wrd260;
  machine_word Wrd257;
  machine_word Wrd275;
  machine_word Wrd189;
  machine_word Wrd270;
  machine_word Wrd267;
  machine_word Wrd186;
  machine_word Wrd302;
  machine_word Wrd299;
  machine_word Wrd298;
  machine_word Wrd288;
  machine_word Wrd292;
  machine_word Wrd291;
  machine_word Wrd294;
  machine_word Wrd293;
  machine_word Wrd287;
  machine_word Wrd281;
  machine_word Wrd280;
  machine_word Wrd279;
  machine_word Wrd283;
  machine_word Wrd282;
  machine_word Wrd323;
  machine_word Wrd317;
  machine_word Wrd316;
  machine_word Wrd319;
  machine_word Wrd318;
  machine_word Wrd314;
  machine_word Wrd308;
  machine_word Wrd307;
  machine_word Wrd305;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd92;
  machine_word Wrd88;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd70;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd78;
  machine_word Wrd68;
  machine_word Wrd105;
  machine_word Wrd102;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd115;
  machine_word Wrd112;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd110;
  machine_word Wrd107;
  machine_word Wrd125;
  machine_word Wrd122;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd135;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd130;
  machine_word Wrd127;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd36;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd44;
  machine_word Wrd34;
  machine_word Wrd146;
  machine_word Wrd143;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd141;
  machine_word Wrd138;
  machine_word Wrd156;
  machine_word Wrd153;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd151;
  machine_word Wrd148;
  machine_word Wrd166;
  machine_word Wrd163;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd176;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd171;
  machine_word Wrd168;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd332;
  machine_word Wrd329;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd325;
  machine_word Wrd324;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_21;

    case 1:
      current_block = (Rpc - LABEL_2_6);
      goto continuation_9;

    case 2:
      current_block = (Rpc - LABEL_2_7);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_2_4);
      goto equalP_55;

    case 4:
      current_block = (Rpc - LABEL_2_8);
      goto label_75;

    case 5:
      current_block = (Rpc - LABEL_2_9);
      goto label_65;

    case 6:
      current_block = (Rpc - LABEL_2_10);
      goto label_64;

    case 7:
      current_block = (Rpc - LABEL_2_11);
      goto label_63;

    case 8:
      current_block = (Rpc - LABEL_2_12);
      goto label_62;

    case 9:
      current_block = (Rpc - LABEL_2_13);
      goto label_61;

    case 10:
      current_block = (Rpc - LABEL_2_14);
      goto label_60;

    case 11:
      current_block = (Rpc - LABEL_2_15);
      goto label_59;

    case 12:
      current_block = (Rpc - LABEL_2_16);
      goto label_58;

    case 13:
      current_block = (Rpc - LABEL_2_17);
      goto label_57;

    case 14:
      current_block = (Rpc - LABEL_2_20);
      goto label_73;

    case 15:
      current_block = (Rpc - LABEL_2_21);
      goto label_74;

    case 16:
      current_block = (Rpc - LABEL_2_23);
      goto label_71;

    case 17:
      current_block = (Rpc - LABEL_2_24);
      goto label_72;

    case 18:
      current_block = (Rpc - LABEL_2_26);
      goto label_70;

    case 19:
      current_block = (Rpc - LABEL_2_27);
      goto label_69;

    case 20:
      current_block = (Rpc - LABEL_2_28);
      goto label_68;

    case 21:
      current_block = (Rpc - LABEL_2_29);
      goto label_67;

    case 22:
      current_block = (Rpc - LABEL_2_31);
      goto label_66;

    case 23:
      current_block = (Rpc - LABEL_2_18);
      goto continuation_16;

    case 24:
      current_block = (Rpc - LABEL_2_30);
      goto continuation_27;

    case 25:
      current_block = (Rpc - LABEL_2_32);
      goto continuation_36;

    case 26:
      current_block = (Rpc - LABEL_2_39);
      goto loop_47;

    case 27:
      current_block = (Rpc - LABEL_2_41);
      goto label_76;

    case 28:
      current_block = (Rpc - LABEL_2_42);
      goto label_77;

    case 29:
      current_block = (Rpc - LABEL_2_19);
      goto continuation_52;

    case 30:
      current_block = (Rpc - LABEL_2_43);
      goto label_78;

    case 31:
      current_block = (Rpc - LABEL_2_44);
      goto label_79;

    case 32:
      current_block = (Rpc - LABEL_2_34);
      goto continuation_17;

    case 33:
      current_block = (Rpc - LABEL_2_37);
      goto continuation_33;

    case 34:
      current_block = (Rpc - LABEL_2_35);
      goto continuation_29;

    case 35:
      current_block = (Rpc - LABEL_2_38);
      goto continuation_37;

    case 36:
      current_block = (Rpc - LABEL_2_40);
      goto continuation_45;

    case 37:
      current_block = (Rpc - LABEL_2_46);
      goto continuation_34;

    case 38:
      current_block = (Rpc - LABEL_2_49);
      goto continuation_32;

    case 39:
      current_block = (Rpc - LABEL_2_47);
      goto continuation_30;

    case 40:
      current_block = (Rpc - LABEL_2_51);
      goto continuation_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (equalP_81)
DEFLABEL (equalP_55)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_158;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  (Wrd7.Obj) = (MAKE_OBJECT (26, (Wrd10.uLng)));
  (Wrd324.Obj) = ((SCHEME_OBJECT) 26);
  if (! ((Wrd324.uLng) == 26))
    goto label_157;
  (Wrd325.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if (! (((unsigned long) (Wrd325.Lng)) < ((unsigned long) (1 << TYPE_CODE_LENGTH))))
    goto label_157;
  Wrd11 = Wrd10;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd11.Obj) == (Wrd13.Obj))
    goto label_117;

DEFLABEL (label_116)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd168.Obj) = (current_block [OBJECT_2_2]);
  (Wrd171.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd171.Lng))))
    goto label_115;
  (Wrd19.uLng) = (OBJECT_DATUM (Wrd168.Obj));
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd19.Obj) == (Wrd21.Obj))
    goto label_108;

DEFLABEL (label_114)
  (Wrd158.Obj) = (current_block [OBJECT_2_3]);
  (Wrd161.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd161.Lng))))
    goto label_113;
  (Wrd23.uLng) = (OBJECT_DATUM (Wrd158.Obj));
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd23.Obj) == (Wrd25.Obj))
    goto label_108;

DEFLABEL (label_112)
  (Wrd148.Obj) = (current_block [OBJECT_2_4]);
  (Wrd151.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd151.Lng))))
    goto label_111;
  (Wrd27.uLng) = (OBJECT_DATUM (Wrd148.Obj));
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd27.Obj) == (Wrd29.Obj))
    goto label_108;

DEFLABEL (label_110)
  (Wrd138.Obj) = (current_block [OBJECT_2_5]);
  (Wrd141.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd141.Lng))))
    goto label_109;
  (Wrd31.uLng) = (OBJECT_DATUM (Wrd138.Obj));
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd31.Obj) == (Wrd33.Obj))
    goto label_108;

DEFLABEL (label_107)
  (Wrd34.Obj) = (current_block [OBJECT_2_6]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd44.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 60L) < ((unsigned long) (Wrd44.Lng)))
    goto label_84;

DEFLABEL (label_83)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_84)
  (Wrd38.uLng) = (OBJECT_DATUM (Wrd34.Obj));
  (Wrd39.Obj) = (Rsp [1]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd38.Obj) == (Wrd40.Obj))
    goto label_86;
  (Wrd36.Obj) = (current_block [OBJECT_2_7]);
  goto label_85;

DEFLABEL (label_86)
  (Wrd36.Obj) = (current_block [OBJECT_2_0]);

DEFLABEL (label_85)
DEFLABEL (label_106)
  Rsp = (& (Rsp [3]));
  if ((Wrd36.Obj) == ((SCHEME_OBJECT) 0))
    goto label_90;

DEFLABEL (label_105)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_6]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd127.Obj) = (current_block [OBJECT_2_2]);
  (Wrd130.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd130.Lng))))
    goto label_104;
  (Wrd53.uLng) = (OBJECT_DATUM (Wrd127.Obj));
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd53.Obj) == (Wrd55.Obj))
    goto label_97;

DEFLABEL (label_103)
  (Wrd117.Obj) = (current_block [OBJECT_2_3]);
  (Wrd120.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd120.Lng))))
    goto label_102;
  (Wrd57.uLng) = (OBJECT_DATUM (Wrd117.Obj));
  (Wrd58.Obj) = (Rsp [0]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if ((Wrd57.Obj) == (Wrd59.Obj))
    goto label_97;

DEFLABEL (label_101)
  (Wrd107.Obj) = (current_block [OBJECT_2_4]);
  (Wrd110.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd110.Lng))))
    goto label_100;
  (Wrd61.uLng) = (OBJECT_DATUM (Wrd107.Obj));
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if ((Wrd61.Obj) == (Wrd63.Obj))
    goto label_97;

DEFLABEL (label_99)
  (Wrd97.Obj) = (current_block [OBJECT_2_5]);
  (Wrd100.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd100.Lng))))
    goto label_98;
  (Wrd65.uLng) = (OBJECT_DATUM (Wrd97.Obj));
  (Wrd66.Obj) = (Rsp [0]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if ((Wrd65.Obj) == (Wrd67.Obj))
    goto label_97;

DEFLABEL (label_96)
  (Wrd68.Obj) = (current_block [OBJECT_2_6]);
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd78.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 60L) < ((unsigned long) (Wrd78.Lng))))
    goto label_83;
  (Wrd72.uLng) = (OBJECT_DATUM (Wrd68.Obj));
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd72.Obj) == (Wrd74.Obj))
    goto label_88;
  (Wrd70.Obj) = (current_block [OBJECT_2_7]);
  goto label_87;

DEFLABEL (label_88)
  (Wrd70.Obj) = (current_block [OBJECT_2_0]);

DEFLABEL (label_87)
DEFLABEL (label_95)
  Rsp = (& (Rsp [3]));
  if ((Wrd70.Obj) == ((SCHEME_OBJECT) 0))
    goto label_90;

DEFLABEL (label_94)
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 26))
    goto label_93;
  (Wrd82.Obj) = (Rsp [1]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd83.uLng) == 26))
    goto label_93;
  if ((Wrd80.Obj) == (Wrd82.Obj))
    goto label_91;

DEFLABEL (label_90)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_89)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_91)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_18]))));
  (* (--Rsp)) = (Wrd92.Obj);

DEFLABEL (label_92)
  (Wrd233.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd233.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_33]));

DEFLABEL (label_93)
  (Wrd84.Obj) = (Rsp [0]);
  (Wrd85.Obj) = (Rsp [1]);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_17]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_57)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_90;
  goto label_91;

DEFLABEL (label_97)
  Rsp = (& (Rsp [2]));
  goto label_94;

DEFLABEL (label_98)
  (Wrd102.Obj) = (Rsp [0]);
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_16]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_58)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_96;
  goto label_97;

DEFLABEL (label_100)
  (Wrd112.Obj) = (Rsp [0]);
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_15]))));
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd107.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_59)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_99;
  goto label_97;

DEFLABEL (label_102)
  (Wrd122.Obj) = (Rsp [0]);
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_14]))));
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd117.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_60)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_101;
  goto label_97;

DEFLABEL (label_104)
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_13]))));
  (* (--Rsp)) = (Wrd135.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd127.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_61)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_103;
  goto label_97;

DEFLABEL (label_108)
  Rsp = (& (Rsp [2]));
  goto label_105;

DEFLABEL (label_109)
  (Wrd143.Obj) = (Rsp [0]);
  (Wrd146.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_12]))));
  (* (--Rsp)) = (Wrd146.Obj);
  (* (--Rsp)) = (Wrd143.Obj);
  (* (--Rsp)) = (Wrd138.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_62)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_107;
  goto label_108;

DEFLABEL (label_111)
  (Wrd153.Obj) = (Rsp [0]);
  (Wrd156.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_11]))));
  (* (--Rsp)) = (Wrd156.Obj);
  (* (--Rsp)) = (Wrd153.Obj);
  (* (--Rsp)) = (Wrd148.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_63)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_110;
  goto label_108;

DEFLABEL (label_113)
  (Wrd163.Obj) = (Rsp [0]);
  (Wrd166.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_10]))));
  (* (--Rsp)) = (Wrd166.Obj);
  (* (--Rsp)) = (Wrd163.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_64)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_112;
  goto label_108;

DEFLABEL (label_115)
  (Wrd176.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_9]))));
  (* (--Rsp)) = (Wrd176.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd168.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_65)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_114;
  goto label_108;

DEFLABEL (label_117)
  (Wrd178.Obj) = (Rsp [1]);
  (Wrd179.uLng) = (OBJECT_TYPE (Wrd178.Obj));
  if ((Wrd179.uLng) == 1)
    goto label_147;
  if ((Wrd179.uLng) == 10)
    goto label_141;
  if (! ((Wrd179.uLng) == 30))
    goto label_118;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_25]));

DEFLABEL (label_118)
  (Wrd186.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd186.Obj);
  (* (--Rsp)) = (Wrd178.Obj);
  (Wrd267.Obj) = (current_block [OBJECT_2_2]);
  (Wrd270.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd270.Lng))))
    goto label_140;
  (Wrd189.uLng) = (OBJECT_DATUM (Wrd267.Obj));
  if ((Wrd189.Obj) == (Wrd179.Obj))
    goto label_133;

DEFLABEL (label_139)
  (Wrd257.Obj) = (current_block [OBJECT_2_3]);
  (Wrd260.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd260.Lng))))
    goto label_138;
  (Wrd193.uLng) = (OBJECT_DATUM (Wrd257.Obj));
  (Wrd194.Obj) = (Rsp [0]);
  (Wrd195.uLng) = (OBJECT_TYPE (Wrd194.Obj));
  if ((Wrd193.Obj) == (Wrd195.Obj))
    goto label_133;

DEFLABEL (label_137)
  (Wrd247.Obj) = (current_block [OBJECT_2_4]);
  (Wrd250.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd250.Lng))))
    goto label_136;
  (Wrd197.uLng) = (OBJECT_DATUM (Wrd247.Obj));
  (Wrd198.Obj) = (Rsp [0]);
  (Wrd199.uLng) = (OBJECT_TYPE (Wrd198.Obj));
  if ((Wrd197.Obj) == (Wrd199.Obj))
    goto label_133;

DEFLABEL (label_135)
  (Wrd237.Obj) = (current_block [OBJECT_2_5]);
  (Wrd240.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd240.Lng))))
    goto label_134;
  (Wrd201.uLng) = (OBJECT_DATUM (Wrd237.Obj));
  (Wrd202.Obj) = (Rsp [0]);
  (Wrd203.uLng) = (OBJECT_TYPE (Wrd202.Obj));
  if ((Wrd201.Obj) == (Wrd203.Obj))
    goto label_133;

DEFLABEL (label_132)
  (Wrd204.Obj) = (current_block [OBJECT_2_6]);
  (* (--Rsp)) = (Wrd204.Obj);
  (Wrd214.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 60L) < ((unsigned long) (Wrd214.Lng))))
    goto label_83;
  (Wrd208.uLng) = (OBJECT_DATUM (Wrd204.Obj));
  (Wrd209.Obj) = (Rsp [1]);
  (Wrd210.uLng) = (OBJECT_TYPE (Wrd209.Obj));
  if ((Wrd208.Obj) == (Wrd210.Obj))
    goto label_120;
  (Wrd206.Obj) = (current_block [OBJECT_2_7]);
  goto label_119;

DEFLABEL (label_120)
  (Wrd206.Obj) = (current_block [OBJECT_2_0]);

DEFLABEL (label_119)
DEFLABEL (label_131)
  Rsp = (& (Rsp [3]));
  if (! ((Wrd206.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_128;

DEFLABEL (label_127)
  (Wrd218.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_30]))));
  (* (--Rsp)) = (Wrd218.Obj);
  (Wrd219.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd219.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_11]), 1);

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_2_30);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_121;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_37]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_13]), 1);

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_2_37);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_46]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_13]), 1);

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_2_46);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (label_121)
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 47))
    goto label_122;
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_12]), 2);

DEFLABEL (label_122)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_35]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_36]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_2_35);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_124;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_49]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_36]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_2_49);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_123;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_50]));

DEFLABEL (label_123)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_124)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_47]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_48]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_2_47);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_125;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_125)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_51]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_48]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_2_51);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_126;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_52]));

DEFLABEL (label_126)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_128)
  (Wrd220.Obj) = (Rsp [0]);
  (Wrd221.uLng) = (OBJECT_TYPE (Wrd220.Obj));
  if (! ((Wrd221.uLng) == 26))
    goto label_130;
  (Wrd222.Obj) = (Rsp [1]);
  (Wrd223.uLng) = (OBJECT_TYPE (Wrd222.Obj));
  if (! ((Wrd223.uLng) == 26))
    goto label_130;
  if (! ((Wrd220.Obj) == (Wrd222.Obj)))
    goto label_90;

DEFLABEL (label_129)
  (Wrd232.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_32]))));
  (* (--Rsp)) = (Wrd232.Obj);
  goto label_92;

DEFLABEL (label_130)
  (Wrd224.Obj) = (Rsp [0]);
  (Wrd225.Obj) = (Rsp [1]);
  (Wrd228.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_31]))));
  (* (--Rsp)) = (Wrd228.Obj);
  (* (--Rsp)) = (Wrd225.Obj);
  (* (--Rsp)) = (Wrd224.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_66)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_90;
  goto label_129;

DEFLABEL (label_133)
  Rsp = (& (Rsp [2]));
  goto label_128;

DEFLABEL (label_134)
  (Wrd242.Obj) = (Rsp [0]);
  (Wrd245.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_29]))));
  (* (--Rsp)) = (Wrd245.Obj);
  (* (--Rsp)) = (Wrd242.Obj);
  (* (--Rsp)) = (Wrd237.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_67)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_132;
  goto label_133;

DEFLABEL (label_136)
  (Wrd252.Obj) = (Rsp [0]);
  (Wrd255.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_28]))));
  (* (--Rsp)) = (Wrd255.Obj);
  (* (--Rsp)) = (Wrd252.Obj);
  (* (--Rsp)) = (Wrd247.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_68)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_135;
  goto label_133;

DEFLABEL (label_138)
  (Wrd262.Obj) = (Rsp [0]);
  (Wrd265.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_27]))));
  (* (--Rsp)) = (Wrd265.Obj);
  (* (--Rsp)) = (Wrd262.Obj);
  (* (--Rsp)) = (Wrd257.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_69)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_137;
  goto label_133;

DEFLABEL (label_140)
  (Wrd275.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_26]))));
  (* (--Rsp)) = (Wrd275.Obj);
  (* (--Rsp)) = (Wrd178.Obj);
  (* (--Rsp)) = (Wrd267.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_70)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_139;
  goto label_133;

DEFLABEL (label_141)
  (Wrd282.Obj) = (Rsp [0]);
  (Wrd283.uLng) = (OBJECT_TYPE (Wrd282.Obj));
  if (! ((Wrd283.uLng) == 10))
    goto label_146;
  (Wrd279.pObj) = (OBJECT_ADDRESS (Wrd282.Obj));
  (Wrd280.Obj) = ((Wrd279.pObj) [0]);
  (Wrd281.Obj) = (MAKE_OBJECT (26, (Wrd280.uLng)));
  (* (--Rsp)) = (Wrd281.Obj);

DEFLABEL (label_145)
  (Wrd293.Obj) = (Rsp [2]);
  (Wrd294.uLng) = (OBJECT_TYPE (Wrd293.Obj));
  if (! ((Wrd294.uLng) == 10))
    goto label_144;
  (Wrd291.pObj) = (OBJECT_ADDRESS (Wrd293.Obj));
  (Wrd292.Obj) = ((Wrd291.pObj) [0]);
  (Wrd288.Obj) = (MAKE_OBJECT (26, (Wrd292.uLng)));

DEFLABEL (label_143)
  (Wrd299.Obj) = (Rsp [0]);
  if ((Wrd299.Obj) == (Wrd288.Obj))
    goto label_142;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_142)
  (Wrd302.Obj) = (current_block [OBJECT_2_10]);
  (* (--Rsp)) = (Wrd302.Obj);
  goto loop_47;

DEFLABEL (label_144)
  (Wrd298.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_24]))));
  (* (--Rsp)) = (Wrd298.Obj);
  (* (--Rsp)) = (Wrd293.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_9]), 1);

DEFLABEL (label_72)
  (Wrd288.Obj) = Rvl;
  goto label_143;

DEFLABEL (label_146)
  (Wrd287.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_23]))));
  (* (--Rsp)) = (Wrd287.Obj);
  (* (--Rsp)) = (Wrd282.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_9]), 1);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_145;

DEFLABEL (label_147)
  (Wrd305.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_19]))));
  (* (--Rsp)) = (Wrd305.Obj);
  if (! ((Wrd179.uLng) == 1))
    goto label_156;
  (Wrd307.pObj) = (OBJECT_ADDRESS (Wrd178.Obj));
  (Wrd308.Obj) = ((Wrd307.pObj) [0]);
  (* (--Rsp)) = (Wrd308.Obj);

DEFLABEL (label_155)
  (Wrd318.Obj) = (Rsp [2]);
  (Wrd319.uLng) = (OBJECT_TYPE (Wrd318.Obj));
  if (! ((Wrd319.uLng) == 1))
    goto label_154;
  (Wrd316.pObj) = (OBJECT_ADDRESS (Wrd318.Obj));
  (Wrd317.Obj) = ((Wrd316.pObj) [0]);
  (* (--Rsp)) = (Wrd317.Obj);

DEFLABEL (label_153)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_2_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_148;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_148)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_152;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_151)
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_150;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_149)
  (Rsp [1]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (label_150)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_44]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_15]), 1);

DEFLABEL (label_79)
  (Wrd16.Obj) = Rvl;
  goto label_149;

DEFLABEL (label_152)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_43]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_15]), 1);

DEFLABEL (label_78)
  (Wrd7.Obj) = Rvl;
  goto label_151;

DEFLABEL (label_154)
  (Wrd323.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_21]))));
  (* (--Rsp)) = (Wrd323.Obj);
  (* (--Rsp)) = (Wrd318.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_8]), 1);

DEFLABEL (label_74)
  (* (--Rsp)) = Rvl;
  goto label_153;

DEFLABEL (label_156)
  (Wrd314.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_20]))));
  (* (--Rsp)) = (Wrd314.Obj);
  (* (--Rsp)) = (Wrd178.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_8]), 1);

DEFLABEL (label_73)
  (* (--Rsp)) = Rvl;
  goto label_155;

DEFLABEL (label_157)
  (Wrd329.Obj) = (Rsp [1]);
  (Wrd332.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd332.Obj);
  (* (--Rsp)) = (Wrd329.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_75)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_116;
  goto label_117;

DEFLABEL (label_158)
  Rvl = (current_block [OBJECT_2_0]);
  goto label_89;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_2_18);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_34]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_33]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_2_34);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_45]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_2_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_90;
  goto label_94;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_90;
  goto label_105;

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_2_32);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_38]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_33]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_2_38);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_45]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_2_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_127;
  goto label_128;

DEFLABEL (loop_82)
DEFLABEL (loop_47)
  INTERRUPT_CHECK (26, LABEL_2_39);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_159;
  Rvl = (current_block [OBJECT_2_0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_159)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_40]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_164;
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_164;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) (Wrd19.Lng)) < ((unsigned long) (Wrd23.Lng))))
    goto label_164;
  (Wrd11.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd14.pObj) = (& ((Wrd21.pObj) [(Wrd11.Lng)]));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_163)
  (Wrd45.Obj) = (Rsp [4]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_162;
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 26))
    goto label_162;
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) (Wrd40.Lng)) < ((unsigned long) (Wrd44.Lng))))
    goto label_162;
  (Wrd32.uLng) = (OBJECT_DATUM (Wrd37.Obj));
  (Wrd35.pObj) = (& ((Wrd42.pObj) [(Wrd32.Lng)]));
  (Wrd36.Obj) = ((Wrd35.pObj) [1]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_161)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_2_40);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_160;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.Lng) = (FIXNUM_TO_LONG (Wrd8.Obj));
  (Wrd10.Lng) = ((Wrd9.Lng) + 1L);
  (Wrd7.Obj) = (LONG_TO_FIXNUM (Wrd10.Lng));
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_47;

DEFLABEL (label_160)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_162)
  (Wrd47.Obj) = (Rsp [4]);
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_42]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_14]), 2);

DEFLABEL (label_77)
  (* (--Rsp)) = Rvl;
  goto label_161;

DEFLABEL (label_164)
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_41]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_14]), 2);

DEFLABEL (label_76)
  (* (--Rsp)) = Rvl;
  goto label_163;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5 3
#define LABEL_6 5
#define LABEL_7 7
#define ENVIRONMENT_LABEL_3 16
#define DEBUGGING_LABEL_2 15
#define PURIFICATION_ROOT 14
#define OBJECT_2 13
#define OBJECT_1 12
#define OBJECT_0 11
#define GLOBAL_EXECUTE_CACHE_4 9
#define FREE_REFERENCES_LABEL_0 8
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
equals_so_a9fb60843c56f5e9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5);
      goto label_4;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_6])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_5)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_4)
  {
    static const short sections [] =
      {
	0,
	1,
	1
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 2)
      goto label_3;
    blocks = (current_block [OBJECT_2]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_3)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_4]));

INVOKE_INTERFACE_TARGET_4
}

static const struct liarc_code_S arr_decl_equals_so_a9fb60843c56f5e9 [2] =
  {
    { "equals_so_code_1", 26, equals_so_code_1 },
    { "equals_so_code_2", 41, equals_so_code_2 }
  };

int
decl_equals_so_a9fb60843c56f5e9 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_equals_so_a9fb60843c56f5e9);
  return (0);
}

DECLARE_COMPILED_CODE ("equals.so", 3, decl_equals_so_a9fb60843c56f5e9, equals_so_a9fb60843c56f5e9)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_equals_so_data_a9fb60843c56f5e9 [895] =
  "\x7b\x07\xe7\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\x02\x06"
  "\x07\x02\x86\x02\x02\x02\xc2\xba\x28\x0d\xbb\x28\x0d\xbc\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x82\x88\xc1\xc2\xc1\xc2\xc1"
  "\x80\xb1\xc1\x06\x02\x86\x02\x02\x02\xb2\x07\x28\x0d\xba\x28\x0d"
  "\x28\xb3\x28\x0d\x28\xb4\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\xbc\x99\xbb\x88\xb3\xb4\x2a\xb5\x2a\x99\xb2\x0d\x99\x28"
  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65"
  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
  "\x69\x6d\x65\x2f\x65\x71\x75\x61\x6c\x73\x2e\x69\x6e\x66\x15\x23"
  "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
  "\x6f\x74\x5d\x02\x0e\x76\x65\x63\x74\x6f\x72\x2d\x6c\x65\x6e\x67"
  "\x74\x68\x0b\x3d\x3b\x0f\x1b\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74"
  "\x79\x70\x65\x3f\x03\x07\x65\x78\x61\x63\x74\x3f\x04\x0a\x62\x6f"
  "\x6f\x6c\x65\x61\x6e\x3d\x3f\x03\x1d\x36\x81\x85\x02\x1c\x34\x81"
  "\x85\x02\x1b\x32\x81\x85\x02\x1a\x30\x81\x85\x02\x19\x2e\x81\x85"
  "\x02\x18\x2c\x81\x85\x02\x17\x2a\x81\x85\x02\x16\x28\x81\x85\x02"
  "\x15\x26\x81\x83\x02\x14\x24\x81\x83\x02\x13\x22\x81\x83\x02\x12"
  "\x20\x81\x83\x02\x11\x1e\x81\x85\x02\x10\x1c\x81\x83\x02\x0f\x1a"
  "\x81\x83\x02\x0e\x18\x81\x83\x02\x0d\x16\x81\x83\x02\x0c\x14\x81"
  "\x83\x02\x0b\x12\x81\x83\x02\x0a\x10\x81\x83\x02\x09\x0e\x81\x83"
  "\x02\x08\x0c\x81\x85\x02\x07\x0a\x84\x06\x06\x08\x81\x85\x02\x05"
  "\x06\x81\x85\x02\x04\x04\x81\x85\x02\x35\x47\x02\x04\x63\x64\x72"
  "\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x0e\x63\x65\x6c\x6c"
  "\x2d\x63\x6f\x6e\x74\x65\x6e\x74\x73\x0d\x62\x69\x74\x2d\x73\x74"
  "\x72\x69\x6e\x67\x3d\x3f\x06\x63\x65\x6c\x6c\x3f\x04\x63\x61\x72"
  "\x3d\x3b\x0f\x1b\x04\x07\x65\x71\x75\x61\x6c\x3f\x04\x09\x73\x74"
  "\x72\x69\x6e\x67\x3d\x3f\x03\x03\x0a\x70\x61\x74\x68\x6e\x61\x6d"
  "\x65\x3f\x04\x03\x0a\x63\x68\x61\x72\x2d\x73\x65\x74\x3f\x04\x0b"
  "\x70\x61\x74\x68\x6e\x61\x6d\x65\x3d\x3f\x04\x0b\x63\x68\x61\x72"
  "\x2d\x73\x65\x74\x3d\x3f\x09\x46\x54\x81\x85\x02\x45\x52\x81\x85"
  "\x02\x44\x50\x81\x85\x02\x43\x4e\x81\x85\x02\x42\x4c\x81\x89\x02"
  "\x41\x4a\x81\x85\x02\x40\x48\x81\x85\x02\x3f\x46\x81\x85\x02\x3e"
  "\x44\x81\x85\x02\x3d\x42\x81\x85\x02\x3c\x40\x81\x85\x02\x3b\x3e"
  "\x81\x85\x02\x3a\x3c\x81\x8d\x02\x39\x3a\x81\x8b\x02\x38\x38\x81"
  "\x89\x02\x37\x36\x81\x85\x02\x36\x34\x81\x85\x02\x35\x32\x81\x85"
  "\x02\x34\x30\x81\x85\x02\x33\x2e\x81\x83\x02\x32\x2c\x81\x83\x02"
  "\x31\x2a\x81\x83\x02\x30\x28\x81\x83\x02\x2f\x26\x81\x87\x02\x2e"
  "\x24\x81\x85\x02\x2d\x22\x81\x89\x02\x2c\x20\x81\x87\x02\x2b\x1e"
  "\x81\x85\x02\x2a\x1c\x81\x83\x02\x29\x1a\x81\x83\x02\x28\x18\x81"
  "\x83\x02\x27\x16\x81\x83\x02\x26\x14\x81\x83\x02\x25\x12\x81\x83"
  "\x02\x24\x10\x81\x83\x02\x23\x0e\x81\x83\x02\x22\x0c\x81\x85\x02"
  "\x21\x0a\x84\x06\x20\x08\x81\x85\x02\x1f\x06\x81\x85\x02\x1e\x04"
  "\x81\x85\x02\x53\x77\x0a\x0a\x05\x65\x71\x76\x3f\x05\x10\x64\x65"
  "\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x03\x08"
  "\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";

SCHEME_OBJECT *
equals_so_data_a9fb60843c56f5e9 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_equals_so_data_a9fb60843c56f5e9 [0]))), (sizeof (prog_equals_so_data_a9fb60843c56f5e9)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_7]));
}

DECLARE_COMPILED_DATA_NS ("equals.so", equals_so_data_a9fb60843c56f5e9)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("equals.so", "1cbe3fb9a1eac83b")
